@@ -244,6 +244,11 @@ def print_stats(subs, archives, distro_subs, distro_files, verbose=False):
     n_subs = len(get_non_empty_subs(subs))
     n_archives = len(get_non_empty_subs(archives))
     n_distro = len(distro_files)
+
+    if n_subs + n_archives == 0:
+        raise _api.Error(
+            "No valid submissions found to compare.")
+
     avg = round(sum(len(s.files) for s in itertools.chain(subs, archives)) / (n_subs + n_archives), 2)
     data = PluralDict(subs=n_subs, archives=n_archives, distro=n_distro, avg=avg)
     fmt = "Found {subs} submission{subs(s)}, {archives} archive submission{archives(s)}, and " \
